@@ -126,7 +126,7 @@ class BaseImage(object):
 
     def get_surface(self):
         """
-        Return the surface object.
+        Return the surface object of the image.
 
         :return: Image surface
         :rtype: :py:class:`pygame.Surface`
@@ -135,24 +135,28 @@ class BaseImage(object):
 
     def get_namefile(self):
         """
-        :return: Return the name of the image file
+        Return the name of the image file.
+
+        :return: Filename
         :rtype: str
         """
         return self._filename
 
     def get_extension(self):
         """
-        :return: Return the extension of the image file
+        Return the extension of the image file.
+
+        :return: File extension
         :rtype: str
         """
         return self._extension
 
     def equals(self, image):
         """
-        Returns true if the image is the same as the object
+        Return true if the image is the same as the object.
 
         :param image: Image object
-        :type image: BaseImage
+        :type image: :py:class:`pygame_menu.baseimage.BaseImage`
         :return: True if the image is the same (note, the surface)
         :rtype: bool
         """
@@ -278,6 +282,8 @@ class BaseImage(object):
 
     def get_drawing_mode(self):
         """
+        Return the image drawing mode.
+
         :return: Image drawing mode
         :rtype: int
         """
