@@ -35,7 +35,6 @@ from uuid import uuid4
 import sys
 import textwrap
 import types
-import warnings
 
 import pygame
 import pygame.gfxdraw as gfxdraw
@@ -86,9 +85,12 @@ class Menu(object):
     :type onclose: callable, None
     :param rows: Number of rows of each column, None if there's only 1 column
     :type rows: int, None
+    :param screen_dimension: List/Tuple representing the dimensions the menu should reference for sizing/positioning, if None pygame is queried for the display mode
+    :type screen_dimension: tuple, list, None
     :param theme: Menu theme object, if None use the default theme
     :type theme: :py:class:`pygame_menu.themes.Theme`
-    :param kwargs: Optional keyword parameters
+    :param kwargs: Optional keyword-parameters
+    :type kwargs: dict
     """
 
     def __init__(self,
@@ -108,6 +110,7 @@ class Menu(object):
                  mouse_visible=True,
                  onclose=None,
                  rows=None,
+                 screen_dimension=None,
                  theme=_themes.THEME_DEFAULT,
                  **kwargs
                  ):
@@ -125,6 +128,7 @@ class Menu(object):
         assert isinstance(mouse_motion_selection, bool)
         assert isinstance(mouse_visible, bool)
         assert isinstance(rows, (int, type(None)))
+        assert isinstance(screen_dimension, (tuple, list, type(None)))
         assert isinstance(theme, _themes.Theme), 'theme bust be an pygame_menu.themes.Theme object instance'
 
         # Assert theme
@@ -136,18 +140,22 @@ class Menu(object):
         # Column/row asserts
         assert columns >= 1, 'number of columns must be greater or equal than 1'
         if columns > 1:
-            assert rows is not None and rows >= 1, 'if columns greater than 1 then rows must be equal or greater than 1'
+            assert rows is not None and rows >= 1, \
+                'if columns greater than 1 then rows must be equal or greater than 1'
         else:
             if columns == 1:
                 if rows is None:
                     rows = 1e6  # Set rows as a big number
                 else:
-                    assert rows > 0, 'number of rows must be greater than 1'
+                    assert rows > 0, \
+                        'number of rows must be greater than 1'
         if column_max_width is not None:
             if isinstance(column_max_width, (int, float)):
-                assert columns == 1, 'column_max_width can be a single number if there is only 1 column'
+                assert columns == 1, \
+                    'column_max_width can be a single number if there is only 1 column'
                 column_max_width = [column_max_width]
-            assert len(column_max_width) == columns, 'column_max_width length must be the same as the number of columns'
+            assert len(column_max_width) == columns, \
+                'column_max_width length must be the same as the number of columns'
             for i in column_max_width:
                 assert isinstance(i, type(None)) or isinstance(i, (int, float)), \
                     'each column max width can be None (no limit) or an integer/float'
@@ -160,14 +168,22 @@ class Menu(object):
         assert width > 0 and height > 0, \
             'menu width and height must be greater than zero'
 
-        # Get window size
-        surface = pygame.display.get_surface()
-        if surface is None:
-            msg = 'pygame surface could not be retrieved, check if pygame.display.set_mode() was called'
-            raise RuntimeError(msg)
-        window_width, window_height = surface.get_size()
+        # Get window size if not given explicitly
+        if screen_dimension is not None:
+            _utils.assert_vector2(screen_dimension)
+            assert screen_dimension[0] > 0, 'screen width has to be higher than zero'
+            assert screen_dimension[1] > 0, 'screen height has to be higher than zero'
+            self._window_size = screen_dimension
+        else:
+            surface = pygame.display.get_surface()
+            if surface is None:
+                raise RuntimeError('pygame surface could not be retrieved, check '
+                                   'if pygame.display.set_mode() was called')
+            self._window_size = surface.get_size()
+
+        window_width, window_height = self._window_size
         assert width <= window_width and height <= window_height, \
-            'menu size ({0}x{1}) must be lower than the size of the window ({2}x{3})'.format(
+            'menu size ({0}x{1}) must be lower or equal than the size of the window ({2}x{3})'.format(
                 width, height, window_width, window_height)
 
         # Generate ID if empty
@@ -248,16 +264,8 @@ class Menu(object):
         self._mouse_visible_default = mouse_visible
 
         # Create Menu bar (title)
-        back_box = kwargs.get('back_box', None)
-        if back_box is not None:  # Check compatibility
-            assert isinstance(back_box, bool)
-            msg = 'back_box Menu constructor parameter moved to Theme.menubar_close_button. ' \
-                  'back_box will be removed in v3.3'
-            warnings.warn(msg)
-        else:  # Use theme
-            back_box = theme.menubar_close_button
         self._menubar = _widgets.MenuBar(
-            back_box=back_box,
+            back_box=theme.menubar_close_button,
             background_color=self._theme.title_background_color,
             mode=self._theme.title_bar_style,
             offsetx=theme.title_offset[0],
@@ -302,7 +310,7 @@ class Menu(object):
 
         # Upon this, no more kwargs should exist, raise exception if there's more
         for invalid_keyword in kwargs.keys():
-            msg = 'Menu constructor parameter {} does not exist'.format(invalid_keyword)
+            msg = 'menu constructor parameter {} does not exist'.format(invalid_keyword)
             raise ValueError(msg)
 
     def get_current(self):
@@ -351,8 +359,8 @@ class Menu(object):
         :type action: :py:class:`pygame_menu.Menu`, :py:class:`pygame_menu.events.MenuAction`, callable, None
         :param args: Additional arguments used by a function
         :type args: any
-        :param kwargs: Additional keyword arguments
-        :type kwargs: any
+        :param kwargs: Additional keyword-arguments
+        :type kwargs: dict
         :return: Widget object
         :rtype: :py:class:`pygame_menu.widgets.Button`
         """
@@ -450,7 +458,7 @@ class Menu(object):
         :param previsualization_width: Previsualization width as a factor of the height
         :type previsualization_width: int, float
         :param kwargs: Additional keyword-parameters
-        :type kwargs: any
+        :type kwargs: dict
         :return: Widget object
         :rtype: :py:class:`pygame_menu.widgets.ColorInput`
         """
@@ -509,8 +517,8 @@ class Menu(object):
         :type scale_smooth: bool
         :param selectable: Image accepts user selection
         :type selectable: bool
-        :param kwargs: Optional keywords arguments
-        :type kwargs: any
+        :param kwargs: Optional keyword-arguments
+        :type kwargs: dict
         :return: Widget object
         :rtype: :py:class:`pygame_menu.widgets.Image`
         """
@@ -562,8 +570,8 @@ class Menu(object):
         :type max_char: int
         :param selectable: Label accepts user selection, if not selectable long paragraphs cannot be scrolled through keyboard
         :type selectable: bool
-        :param kwargs: Optional keywords arguments
-        :type kwargs: any
+        :param kwargs: Optional keyword-arguments
+        :type kwargs: dict
         :return: Widget object or List of widgets if the text overflows
         :rtype: :py:class:`pygame_menu.widgets.Label`, list[:py:class:`pygame_menu.widgets.Label`]
         """
@@ -655,8 +663,8 @@ class Menu(object):
         :type onreturn: callable, None
         :param selector_id: ID of the selector
         :type selector_id: str
-        :param kwargs: Additional parameters
-        :type kwargs: any
+        :param kwargs: Additional keyword-parameters
+        :type kwargs: dict
         :return: Widget object
         :rtype: :py:class:`pygame_menu.widgets.Selector`
         """
@@ -750,7 +758,7 @@ class Menu(object):
         :param valid_chars: List of authorized chars, None if all chars are valid
         :type valid_chars: list
         :param kwargs: Additional keyword-parameters
-        :type kwargs: any
+        :type kwargs: dict
         :return: Widget object
         :rtype: :py:class:`pygame_menu.widgets.TextInput`
         """
@@ -811,7 +819,7 @@ class Menu(object):
 
     def _filter_widget_attributes(self, kwargs):
         """
-        Return valid widgets attributes from a dictionary.
+        Return the valid widgets attributes from a dictionary.
         The valid (key, value) are removed from the initial
         dictionary.
 
@@ -912,14 +920,16 @@ class Menu(object):
         :param widget: Widget object
         :type widget: :py:class:`pygame_menu.widgets.core.widget.Widget`
         :param kwargs: Optional keywords arguments
-        :type kwargs: any
+        :type kwargs: dict
         :return: None
         """
         assert isinstance(widget, _widgets.core.Widget)
         assert widget.get_menu() is None, 'widget cannot have an instance of menu'
+
         _col = int((len(self._widgets) - 1) // self._rows)  # Column position
         widget.set_menu(self)
         self._check_id_duplicated(widget.get_id())
+
         widget.set_font(
             font=kwargs['font_name'],
             font_size=kwargs['font_size'],
@@ -928,8 +938,12 @@ class Menu(object):
             background_color=kwargs['font_background_color'],
             antialias=kwargs['font_antialias']
         )
+
+        selection_effect = kwargs['selection_effect']  # type: _widgets.core.Selection
+
         if self._force_fit_text and self._column_max_width[_col] is not None:
-            widget.set_max_width(self._column_max_width[_col] - kwargs['selection_effect'].get_width())
+            widget.set_max_width(self._column_max_width[_col] - selection_effect.get_width())
+
         widget.set_shadow(
             enabled=kwargs['shadow'],
             color=kwargs['shadow_color'],
@@ -939,7 +953,7 @@ class Menu(object):
         widget.set_controls(self._joystick, self._mouse)
         widget.set_alignment(kwargs['align'])
         widget.set_margin(*kwargs['margin'])
-        widget.set_selection_effect(kwargs['selection_effect'])
+        widget.set_selection_effect(selection_effect)
         widget.set_background_color(kwargs['background_color'], kwargs['background_inflate'])
 
     def _append_widget(self, widget):
@@ -948,6 +962,7 @@ class Menu(object):
 
         :param widget: Widget object
         :type widget: :py:class:`pygame_menu.widgets.core.widget.Widget`
+        :return: None
         """
         assert isinstance(widget, _widgets.core.Widget)
         assert widget.get_menu() == self, 'widget cannot have a different instance of menu'
@@ -1123,7 +1138,7 @@ class Menu(object):
 
     def _get_widget_max_position(self):
         """
-        Returns the lower rightmost position of each widgets in Menu.
+        Return the lower rightmost position of each widgets in Menu.
 
         :return: Rightmost position
         :rtype: tuple
@@ -1218,9 +1233,9 @@ class Menu(object):
 
     def _get_depth(self):
         """
-        Find Menu depth.
+        Return the Menu depth.
 
-        :return: Depth
+        :return: Menu depth
         :rtype: int
         """
         if self._top is None:
@@ -1268,7 +1283,7 @@ class Menu(object):
 
         position_x = float(position_x) / 100
         position_y = float(position_y) / 100
-        window_width, window_height = pygame.display.get_surface().get_size()
+        window_width, window_height = self._window_size
         self._pos_x = (window_width - self._width) * position_x
         self._pos_y = (window_height - self._height) * position_y
         self._widgets_surface = None  # This forces an update of the widgets
@@ -1358,7 +1373,7 @@ class Menu(object):
 
         if widget is None or not widget.active or not self._mouse_motion_selection:
             return
-        window_width, window_height = pygame.display.get_surface().get_size()
+        window_width, window_height = self._window_size
 
         rect = widget.get_rect()
         if widget.selected and widget.get_selection_effect():
@@ -1428,7 +1443,9 @@ class Menu(object):
 
     def is_enabled(self):
         """
-        :return: True if the Menu is enabled
+        Return True if the menu is enabled.
+
+        :return: Menu enabled status
         :rtype: bool
         """
         return self._top._enabled
@@ -1735,7 +1752,7 @@ class Menu(object):
                 subdata_keys = data_submenu.keys()
                 for key in subdata_keys:  # type: str
                     if key in data_keys:
-                        msg = 'Collision between widget data ID="{0}" at depth={1}'.format(key, depth)
+                        msg = 'collision between widget data ID="{0}" at depth={1}'.format(key, depth)
                         raise ValueError(msg)
 
                 # Update data
@@ -1744,7 +1761,7 @@ class Menu(object):
 
     def get_rect(self):
         """
-        Return Menu rect.
+        Return the Menu rect.
 
         :return: Rect
         :rtype: :py:class:`pygame.Rect`
@@ -1765,7 +1782,8 @@ class Menu(object):
         :type recursive: bool
         :return: None
         """
-        assert isinstance(sound, (type(self._sounds), type(None))), 'sound must be pygame_menu.Sound type or None'
+        assert isinstance(sound, (type(self._sounds), type(None))), \
+            'sound must be pygame_menu.Sound type or None'
         if sound is None:
             sound = Sound()
         self._sounds = sound
@@ -1914,13 +1932,32 @@ class Menu(object):
 
     def get_id(self):
         """
-        Returns the ID of the current/base Menu.
+        Return the ID of the current/base Menu.
 
         :return: Menu ID
         :rtype: str
         """
         return self._id
 
+    def get_window_size(self):
+        """
+        Return the window size (px) as a tuple of (width, height).
+
+        :return: Window size in px
+        :rtype: tuple
+        """
+        w, h = self._window_size
+        return w, h
+
+    def get_size(self):
+        """
+        Return the Menu size (px) as a tuple of (width, height).
+
+        :return: Menu size in px
+        :rtype: tuple
+        """
+        return self._width, self._height
+
     def get_widget(self, widget_id, recursive=False):
         """
         Return a widget by a given ID from the Menu.
