@@ -153,21 +153,27 @@ class ScrollBar(Widget):
 
     def get_maximum(self):
         """
-        :return: Return the greatest acceptable value
+        Return the greatest acceptable value.
+
+        :return: Greatest acceptable value
         :rtype: int
         """
         return self._values_range[1]
 
     def get_minimum(self):
         """
-        :return: Return the smallest acceptable value
+        Return the smallest acceptable value.
+
+        :return: Smallest acceptable value
         :rtype: int
         """
         return self._values_range[0]
 
     def get_orientation(self):
         """
-        :return: Return the scroll bar orientation
+        Return the scrollbar orientation (pygame-menu locals).
+
+        :return: Scrollbar orientation
         :rtype: str
         """
         if self._orientation == 0:
@@ -177,7 +183,10 @@ class ScrollBar(Widget):
 
     def get_page_step(self):
         """
-        :return: Return amount that the value changes by when the user click on the page control surface
+        Return amount that the value changes by when the user
+        click on the page control surface.
+
+        :return: Page step
         :rtype: int
         """
         return self._page_step * (self._values_range[1] - self._values_range[0]) / \
@@ -273,7 +282,7 @@ class ScrollBar(Widget):
         :return: None
         """
         assert isinstance(value, (int, float))
-        assert value > self._values_range[0], 'Maximum value shall greater than {}'.format(self._values_range[0])
+        assert value > self._values_range[0], 'maximum value shall greater than {}'.format(self._values_range[0])
         self._values_range[1] = value
 
     def set_minimum(self, value):
@@ -285,7 +294,7 @@ class ScrollBar(Widget):
         :return: None
         """
         assert isinstance(value, (int, float))
-        assert 0 <= value < self._values_range[1], "Minimum value shall lower than {}".format(self._values_range[1])
+        assert 0 <= value < self._values_range[1], 'minimum value shall lower than {}'.format(self._values_range[1])
         self._values_range[0] = value
 
     def set_orientation(self, orientation):
@@ -317,7 +326,7 @@ class ScrollBar(Widget):
         :return: None
         """
         assert isinstance(value, (int, float))
-        assert 0 < value, 'Page step shall be > 0'
+        assert 0 < value, 'page step shall be > 0'
 
         # Slider length shall represent the same ratio
         self._page_step = round(1.0 * self._page_ctrl_length * value /
