@@ -119,7 +119,7 @@ class TextInput(Widget):
     :param valid_chars: List of chars that are valid, None if all chars are valid
     :type valid_chars: list
     :param kwargs: Optional keyword-arguments for callbacks
-    :type kwargs: any
+    :type kwargs: dict
     """
 
     def __init__(self,
@@ -257,8 +257,8 @@ class TextInput(Widget):
             for ch in range(len(valid_chars)):
                 _char = to_string(valid_chars[ch])
                 valid_chars[ch] = _char
-                assert isinstance(_char, str), 'Element "{0}" of valid_chars must be a string'.format(_char)
-                assert len(_char) == 1, 'Element "{0}" of valid_chars must be character'.format(_char)
+                assert isinstance(_char, str), 'element "{0}" of valid_chars must be a string'.format(_char)
+                assert len(_char) == 1, 'element "{0}" of valid_chars must be character'.format(_char)
             assert len(valid_chars) > 0, 'valid_chars list must contain at least 1 element'
         self._valid_chars = valid_chars
 
@@ -300,7 +300,8 @@ class TextInput(Widget):
             password_size = self._font_render_string(self._password_char).get_size()[0]
             if password_size == 0:
                 raise ValueError(
-                    'Password character is not valid, the size of the font is zero, use another character or change the font')
+                    'password character is not valid, the size of the font is zero, '
+                    'use another character or change the font')
             self._keychar_size[self._password_char] = password_size
 
     def clear(self):
@@ -317,7 +318,7 @@ class TextInput(Widget):
 
     def get_value(self):
         """
-        Returns the value of the text.
+        Return the value of the text.
 
         :return: Text inside the widget
         :rtype: str
@@ -619,7 +620,7 @@ class TextInput(Widget):
 
     def _get_input_string_filtered(self):
         """
-        Returns input string where all filters have been applied.
+        Return the input string where all filters have been applied.
 
         :return: Filtered string
         :rtype: str
@@ -634,7 +635,7 @@ class TextInput(Widget):
 
     def _get_input_string(self, add_ellipsis=True):
         """
-        Return input string, apply overflow if enabled.
+        Return the input string, apply overflow if enabled.
 
         :param add_ellipsis: Adds ellipsis text
         :type add_ellipsis: bool
@@ -1043,7 +1044,7 @@ class TextInput(Widget):
 
     def _get_selected_text(self):
         """
-        Return text selected.
+        Return the selected text.
 
         :return: Text
         :rtype: str
@@ -1117,7 +1118,7 @@ class TextInput(Widget):
         """
         Cut operation.
 
-        :return:
+        :return: None
         """
         self._copy()  # This is a safe operation, all checks have been passed
 
@@ -1134,9 +1135,12 @@ class TextInput(Widget):
 
     def _get_char_size(self, char):
         """
-        Return char size in pixels.
+        Return the widget char size in pixels.
 
         :param char: Char
+        :type char: str
+        :return: Char size in px
+        :rtype: int
         """
         if char in self._keychar_size.keys():
             return self._keychar_size[char]
@@ -1415,6 +1419,7 @@ class TextInput(Widget):
 
                     # If test, disable CTRL
                     if 'test' in event.dict and event.dict['test']:
+                        # noinspection PyArgumentList
                         pygame.key.set_mods(pygame.KMOD_NONE)
 
                     # Ctrl+C copy
@@ -1671,6 +1676,7 @@ class TextInput(Widget):
         self._keyrepeat_mouse_ms += time_clock
 
         # Check mouse pressed
+        # noinspection PyArgumentList
         mouse_left, mouse_middle, mouse_right = pygame.mouse.get_pressed()
         self._mouse_is_pressed = mouse_left or mouse_right or mouse_middle
 
